@@ -10,7 +10,7 @@
 #' @return It invisibly returns the user.
 #' @seealso \code{\link[ecmwfr]{wf_get_key}}
 #' @export
-#' @author Koen Kufkens
+#' @author Koen Hufkens
 #' @examples
 #'
 #' \dontrun{
@@ -26,21 +26,21 @@
 #'
 #'}
 #' @importFrom utils browseURL
-wf_set_key <- function(user, key, service){
-
-  if(keyring::default_backend()$name != "env"){
-    if(keyring::keyring_is_locked()){
-      message("Your keyring is locked please unlock with your keyring password!")
+wf_set_key <- function(user, key, service) {
+  if (keyring::default_backend()$name != "env") {
+    if (keyring::keyring_is_locked()) {
+      message("Your keyring is locked please
+              unlock with your keyring password!")
       keyring::keyring_unlock()
     }
   }
 
-  if(missing(service)){
+  if (missing(service)) {
     stop("Please provide a service for which
          to set your API key ('webapi' or 'cds')")
   }
 
-  if(missing(user) | missing(key)) {
+  if (missing(user) | missing(key)) {
     if (!interactive()) {
       stop("wf_set_key needs to be run interactivelly if `user` or `key` are
            not provided.")
@@ -49,7 +49,8 @@ wf_set_key <- function(user, key, service){
     message("Login or register to get a key")
     user <- readline("User ID / email: ")
     key <- getPass::getPass(msg = "API key: ")
-    if (is.null(key)) stop("No key supplied.")
+    if (is.null(key))
+      stop("No key supplied.")
   }
 
   # check login
@@ -60,9 +61,11 @@ wf_set_key <- function(user, key, service){
   if (!login_ok) {
     stop("Could not validate login information.")
   } else {
-    keyring::key_set_with_value(service = make_key_service(service),
-                                username = user,
-                                password = key)
+    keyring::key_set_with_value(
+      service = make_key_service(service),
+      username = user,
+      password = key
+    )
     message("User ", user, " for ", service, " service added successfully")
     return(invisible(user))
   }
